==> java-gnome-4.0.5.tar.bz2: java-gnome-4.0.5/src/bindings/org/gnome/gtk/Value.java <==
/*
 * Value.java
 *
 * Copyright (c) 2006-2007 Operational Dynamics Consulting Pty Ltd
 * 
 * The code in this file, and the library it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 */
package org.gnome.gtk;

/**
 * Wrap real Value class so that we can keep the visibility of its methods
 * restricted. See {@link org.gnome.glib.Value Value} for all the details.
 * 
 * @author Andrew Cowie
 * @author Vreixo Formoso
 * @since 4.0.4
 */
/*
 * This is cut and paste hell, so be careful. Make sure unit tests in
 * org.gnome.gtk do not import org.gnome.glib.Value.
 */
class Value extends org.gnome.glib.Value
{
    protected Value(long pointer) {
        super(pointer);
    }

    Value() {
        super();
    }

    Value(String value) {
        super(value);
    }

    protected String getString() {
        return super.getString();
    }

    Value(int value) {
        super(value);
    }

    protected int getInteger() {
        return super.getInteger();
    }

    Value(boolean value) {
        super(value);
    }

    protected boolean getBoolean() {
        return super.getBoolean();
    }

    Value(float f) {
        super(f);
    }

    public Value(org.gnome.glib.Object obj) {
        super(obj);
    }

    /*
     * Used by things like Pixbuf which is a GObject, not a GtkObject!
     */
    public org.gnome.glib.Object getObject() {
        return super.getObject();
    }

    protected float getFloat() {
        return super.getFloat();
    }
}

==> java-gnome-4.0.6.tar.bz2: java-gnome-4.0.6/src/bindings/org/gnome/gtk/Value.java <==
/*
 * Value.java
 *
 * Copyright (c) 2006-2007 Operational Dynamics Consulting Pty Ltd
 * 
 * The code in this file, and the library it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 */
package org.gnome.gtk;

/**
 * Wrap real Value class so that we can keep the visibility of its methods
 * restricted. See {@link org.gnome.glib.Value Value} for all the details.
 * 
 * @author Andrew Cowie
 * @author Vreixo Formoso
 * @since 4.0.4
 */
/*
 * This is cut and paste hell, so be careful. Make sure unit tests in
 * org.gnome.gtk do not import org.gnome.glib.Value.
 */
class Value extends org.gnome.glib.Value
{
    protected Value(long pointer, boolean proxy) {
        super(pointer, proxy);
    }

    Value() {
        super();
    }

    Value(String value) {
        super(value);
    }

    protected String getString() {
        return super.getString();
    }

    Value(int value) {
        super(value);
    }

    protected int getInteger() {
        return super.getInteger();
    }

    Value(boolean value) {
        super(value);
    }

    protected boolean getBoolean() {
        return super.getBoolean();
    }

    Value(float value) {
        super(value);
    }

    public Value(org.gnome.glib.Object obj) {
        super(obj);
    }

    /*
     * Used by things like Pixbuf which is a GObject, not a GtkObject!
     */
    public org.gnome.glib.Object getObject() {
        return super.getObject();
    }

    protected float getFloat() {
        return super.getFloat();
    }
    
    Value(long value) {
        super(value);
    }

    protected long getLong() {
        return super.getLong();
    }
}
